/*
 * Copyright (c) 2008
 *      The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that: (1) source code distributions
 * retain the above copyright notice and this paragraph in its entirety, (2)
 * distributions including binary code include the above copyright notice and
 * this paragraph in its entirety in the documentation or other materials
 * provided with the distribution, and (3) all advertising materials mentioning
 * features or use of this software display the following acknowledgement:
 * ``This product includes software developed by the University of California,
 * Lawrence Berkeley Laboratory and its contributors.'' Neither the name of
 * the University nor the names of its contributors may be used to endorse
 * or promote products derived from this software without specific prior
 * written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef lint
static const char copyright[] =
    "@(#) Copyright (c) 2008\n\
The Regents of the University of California.  All rights reserved.\n";
static const char rcsid[] =
    "@(#) $Id: common.c 9 2008-10-25 01:56:33Z leres $ (LBL)";
#endif

#include <sys/types.h>

#include <errno.h>
#ifdef HAVE_MALLOC_H
#include <malloc.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sysexits.h>

#include <broccoli.h>

#include "common.h"

/*
 * common - example broccoli common code
 */

int
extractlong(BroRecord *rec, const char *name, long *lp)
{
	int btype;
	long *blp;

	btype = BRO_TYPE_INT;
	blp = bro_record_get_named_val(rec, name, &btype);
	if (blp == NULL) {
		*lp = 0;
		return (0);
	}
	*lp = *blp;
	return (1);
}

int
extractstr(BroRecord *rec, const char *name, char *str, size_t size)
{
	int btype;
	BroString *bstr;

	btype = BRO_TYPE_STRING;
	bstr = bro_record_get_named_val(rec, name, &btype);
	if (bstr == NULL)
		return (0);
	if (size > bstr->str_len + 1)
		size = bstr->str_len + 1;
	strncpy(str, bstr->str_val, size);
	str[size] = '\0';
	bro_string_cleanup(bstr);
	return (1);
}

int
extractuint32(BroRecord *rec, const char *name, uint32 *up)
{
	int btype;
	uint32 *bup;

	btype = BRO_TYPE_COUNT;
	bup = bro_record_get_named_val(rec, name, &btype);
	if (bup == NULL) {
		*up = 0;
		return (0);
	}
	*up = *bup;
	return (1);
}


void *
new(size_t num, size_t size, const char *what)
{
	void *p;

	p = calloc(num, size);
	if (p == NULL) {
		fprintf(stderr, "%s: new: calloc %s: %s\n",
		    prog, what, strerror(errno));
		exit(EX_OSERR);
	}
	return (p);
}
